package com.chinaitop.depot.business.service.impl;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.mapper.BusinessNoticeReceiveMapper;
import com.chinaitop.depot.business.model.BusinessApproval;
import com.chinaitop.depot.business.model.BusinessContractReceive;
import com.chinaitop.depot.business.model.BusinessNoticeReceive;
import com.chinaitop.depot.business.model.BusinessNoticeReceiveExample;
import com.chinaitop.depot.business.model.BusinessNoticeReceiveExample.Criteria;
import com.chinaitop.depot.business.service.BusinessApprovalService;
import com.chinaitop.depot.business.service.BusinessContractReceiveService;
import com.chinaitop.depot.business.service.FeignAgileService;
import com.chinaitop.depot.business.service.FeignBasicService;
import com.chinaitop.depot.business.service.ReceiveNoticeService;
import com.chinaitop.depot.business.service.SystemOutsideDataService;
import com.chinaitop.depot.system.service.SysCodeService;
import com.chinaitop.depot.utils.HTTPUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;

@Service
public class ReceiveNoticeServiceImpl implements ReceiveNoticeService {

	@Resource
    private BusinessNoticeReceiveMapper businessNoticeReceiveMapper;
	@Resource
	private FeignBasicService feignBasicService;
	@Resource
	private FeignAgileService feignAgileService;
	@Resource
    private BusinessApprovalService businessApprovalService;
	@Resource
	private BusinessContractReceiveService businessContractReceiveService;
	@Resource
	private SysCodeService sysCodeService;
	@Resource
	private SystemOutsideDataService systemOutsideDataService;

	public static final Logger logger = LoggerFactory.getLogger(ReceiveNoticeServiceImpl.class);
    /*@Resource
    private BusinessApprovalMapper approvalMapper;*/

	
	// 获取ip地址
    @Value("${crk-webservice}")
    private String url;
    
	@Override
	public List<BusinessNoticeReceive> queryByExample(Integer pageNum, Integer pageSize,
			BusinessNoticeReceive businessNoticeReceive,String cktzd,String lyflag) {
		// TODO Auto-generated method stub
		
		BusinessNoticeReceiveExample example = new BusinessNoticeReceiveExample();
        Criteria createCriteria = example.createCriteria();
        
        if(lyflag!=null){
        	if(lyflag.equals("0")){//油
        		createCriteria.andHouseIdIsNotNull();
        		createCriteria.andWareHouseIdIsNull();
        	}else if(lyflag.equals("1")){//粮
        		createCriteria.andHouseIdIsNotNull();
        		createCriteria.andWareHouseIdIsNotNull();
        	}
        }else{
        	//仓房
            if(businessNoticeReceive.getHouseId()!=null){
            	createCriteria.andHouseIdEqualTo(businessNoticeReceive.getHouseId());
            }
            //货位
            if(businessNoticeReceive.getWareHouseId()!=null){
            	createCriteria.andWareHouseIdEqualTo(businessNoticeReceive.getWareHouseId());
            }
        }
        
        //出入库类型
        if(businessNoticeReceive.getCrktype()!=null && businessNoticeReceive.getCrktype()!=""){
        	createCriteria.andCrktypeEqualTo(businessNoticeReceive.getCrktype());
        }
		//业务类型  竞买 销售 轮换
        if(cktzd!=null && cktzd.equals("0")){
        	if(businessNoticeReceive.getYwtype()!=null && businessNoticeReceive.getYwtype()!=""){
            	createCriteria.andYwtypeNotEqualTo(businessNoticeReceive.getYwtype());
            }
        }else{
        	if(businessNoticeReceive.getYwtype()!=null && businessNoticeReceive.getYwtype()!=""){
            	createCriteria.andYwtypeEqualTo(businessNoticeReceive.getYwtype());
            }
        }
        
        //组织id
        if(businessNoticeReceive.getOrgId()!=null){
        	createCriteria.andOrgIdEqualTo(businessNoticeReceive.getOrgId());
        }
        //通知单编号
        if(businessNoticeReceive.getNoticeNumber()!=null && businessNoticeReceive.getNoticeNumber()!=""){
        	createCriteria.andNoticeNumberEqualTo(businessNoticeReceive.getNoticeNumber());
        }
        //品种
        if(businessNoticeReceive.getGrainKind()!=null){
        	createCriteria.andGrainKindEqualTo(businessNoticeReceive.getGrainKind());
        }
        //性质
        if(businessNoticeReceive.getGrainAttribute()!=null){
        	createCriteria.andGrainAttributeEqualTo(businessNoticeReceive.getGrainAttribute());
        }
        //等级
        if(businessNoticeReceive.getGrainGrade()!=null){
        	createCriteria.andGrainGradeEqualTo(businessNoticeReceive.getGrainGrade());
        }
        //审批通过的
        if(businessNoticeReceive.getAuditState() != null){
        	if(businessNoticeReceive.getAuditState().equals(14)){ //未审批结束的
        		createCriteria.andAuditStateNotEqualTo(5);//5是审批结束的
        	}else{
        		createCriteria.andAuditStateEqualTo(businessNoticeReceive.getAuditState());
        	}
        }
        //是否是可以引用的通知单
        if(businessNoticeReceive.getIsNotice()!=null){
        	createCriteria.andIsNoticeEqualTo(businessNoticeReceive.getIsNotice());
        }
        if(businessNoticeReceive.getIsSheet()!=null){
        	createCriteria.andIsSheetEqualTo(businessNoticeReceive.getIsSheet());
        }
        if(pageNum!=null && pageSize!=null){
        	PageHelper.startPage(pageNum, pageSize);
        }
        example.setOrderByClause("receive_time desc");
        List<BusinessNoticeReceive> selectByExample = businessNoticeReceiveMapper.selectByExample(example);
        return selectByExample;
	}


	
	@Override
	public BusinessNoticeReceive findById(Integer id) {
		// TODO Auto-generated method stub
		return businessNoticeReceiveMapper.selectByPrimaryKey(id);
	}



	@Override
	public void update(BusinessNoticeReceive businessNoticeReceive) {
		// TODO Auto-generated method stub
		businessNoticeReceiveMapper.updateByPrimaryKeySelective(businessNoticeReceive);
	}



	@Override
	public Map<String, Object> receiveNotice(String notice) throws Exception {

        Map<String, Object> modelMap = new HashMap<String, Object>();

        if(notice!=null){
            // JSON字符串转对象
            JSONObject jsonObject = JSONObject.parseObject(notice);
            BusinessNoticeReceive businessNoticeReceive = new BusinessNoticeReceive();
            businessNoticeReceive.setNoticeNumber(jsonObject.getString("tzdid")); //接收通知单编号
            
            /**
             * 根据通知单编号查询是否存在 存在则更改出库期限时间
             * 否则 新增数据
             */

            BusinessNoticeReceiveExample example = new BusinessNoticeReceiveExample();
            Criteria createCriteria = example.createCriteria();
            createCriteria.andNoticeNumberEqualTo(jsonObject.getString("tzdid"));
            List<BusinessNoticeReceive> selectByExample = businessNoticeReceiveMapper.selectByExample(example);
            
            if(selectByExample.size()>0){//存在修改
                BusinessNoticeReceive record = new BusinessNoticeReceive();
                record.setId(selectByExample.get(0).getId());
                record.setOutgoingPeriod(jsonObject.getString("ckqx"));
            	int k = businessNoticeReceiveMapper.updateByPrimaryKeySelective(record);
            	if(k<0){
                    modelMap.put("status", "error");
            	}
            }else{
            	/**
            	 * 新增
            	 */
            	
            	if(jsonObject.getString("tzdlx")!=null && jsonObject.getString("ywlx")!=null){
                    if(ObjectUtils.toString(jsonObject.getString("tzdlx")).equals("01")){ //出入库类型(01：出库 02:入库 03:出入库)
                        businessNoticeReceive.setCrktype("3"); //1入 3出
                        businessNoticeReceive.setForwardingUnit(jsonObject.getString("khssyqmc")); //发货单位
                    }else if (ObjectUtils.toString(jsonObject.getString("tzdlx")).equals("02")){
                        businessNoticeReceive.setCrktype("1"); //1入 3出
                        businessNoticeReceive.setReceiveUnit(jsonObject.getString("ssyqmc")); //收货单位
                    }else if(ObjectUtils.toString(jsonObject.getString("tzdlx")).equals("03")){
                        businessNoticeReceive.setCrktype("13"); //1入 3出
                        businessNoticeReceive.setForwardingUnit(jsonObject.getString("khssyqmc")); //发货单位
                    }

                    if(ObjectUtils.toString(jsonObject.getString("ywlx")).equals("6")){  //业务类型 (6:竞买=入库竞价；7：销售=出库竞价  4：轮换=出库包干)
                        businessNoticeReceive.setYwtype("1"); //1收储=竞买=竞价 2 销售=竞价 3轮换=包干
                    }else if (ObjectUtils.toString(jsonObject.getString("ywlx")).equals("4")){
                        businessNoticeReceive.setYwtype("3");
                    }else if (ObjectUtils.toString(jsonObject.getString("ywlx")).equals("7")){
                        businessNoticeReceive.setYwtype("2");
                    }

                    businessNoticeReceive.setContractNumber(jsonObject.getString("sshtbm")); //协议编号/合同编号

                    String hwbm = jsonObject.getString("cfbm");
                    if(hwbm!=null){
                        Integer grainAttribute = 0 ;
                        Integer grainKind = 0;
                        //根据仓房编码查询仓房、货位、组织机构数据
                        Map<String, Object> wareDataMap = feignBasicService.getWareDataByHwbm(hwbm);
                        logger.info("根据值"+hwbm+"获取到的货位数据如下：");
            			logger.info(wareDataMap+"");
                        if (null == wareDataMap || 
                        		"0".equals(wareDataMap.get("houseId").toString()) || 
                        		"0".equals(wareDataMap.get("wareHouseId").toString()) || 
                        		"0".equals(wareDataMap.get("orgId").toString())) {

                            modelMap.put("msg", "根据值"+hwbm+"未获取到对应仓房货位信息，请核对数据");
                            modelMap.put("status", "error");

                        } else {
                            Integer houseId = (Integer) wareDataMap.get("houseId");
                            Integer wareHouseId = (Integer) wareDataMap.get("wareHouseId");
                            Integer orgId = (Integer) wareDataMap.get("orgId");
                            businessNoticeReceive.setHouseId(houseId); //仓房
                            businessNoticeReceive.setWareHouseId(wareHouseId); //货位
                            businessNoticeReceive.setOrgId(orgId);  //组织id
                            if(ObjectUtils.toString(jsonObject.getString("ywlx")).equals("6")){//入库竞价的业务类型
                                if(jsonObject.getString("pz")!=null){
                                    String code = jsonObject.getString("pzbm");//品种编码
                                    if (StringUtils.isNotBlank(code)) {
                                        code = code.substring(0,3);//获取前三位
                                        Map<String, Object> basicMap = feignBasicService.getIdByNameAndParentId(1061, null, code);//1061是粮食品种的父ID
                                        logger.info("获取到的品种数据如下：");
                            			logger.info(basicMap.toString());
                                        businessNoticeReceive.setGrainKind((Integer) basicMap.get("enumId")); //接收的品种大类
                                    }
                                }
                            }else{
                                //根据仓房、货位、orgId获取粮食品种等信息
                                Map<String, Object> map = feignAgileService.getDateByChHwh(orgId, houseId, wareHouseId);
                                grainAttribute = (Integer) map.get("hwxz"); //粮油性质
                                grainKind = (Integer) map.get("pz"); //品种
                                Integer grainDetailKind = (Integer) map.get("mxpz"); //明细品种
                                Integer grainGrade = (Integer) map.get("dj"); //等级
                                String inputTime = map.get("rq")+""; //入库时间
                                Integer scnf = Integer.parseInt(map.get("scnf")+"");
                                Double kcsl = (Double) map.get("kcsl");//千克
                                Date date = null;
                                if(inputTime!=null){
                                    date = ParameterUtil.string2datetime(inputTime);
                                    businessNoticeReceive.setInputTime(date);//入库时间
                                }
                                businessNoticeReceive.setProductiveYear(scnf);//生产年份
                                businessNoticeReceive.setGrainAnnual(scnf);//收获年度

                                Integer grainProducingArea = (Integer) map.get("gb"); //产地

                                businessNoticeReceive.setGrainKind(grainKind); //品种
                                businessNoticeReceive.setGrainDetailKind(grainDetailKind); //明细品种
                                businessNoticeReceive.setGrainGrade(grainGrade); //等级
                                businessNoticeReceive.setGrainAttribute(grainAttribute); //粮油性质
                                businessNoticeReceive.setGrainProducingArea(grainProducingArea);//产地
                                
                                /**
                                 * 库存数量转化为吨
                                 */
                                BigDecimal s = new BigDecimal(1000);
                                BigDecimal kcslBig = new BigDecimal(kcsl);
                                BigDecimal kcslKg = kcslBig.divide(s);
                                
                                businessNoticeReceive.setLssl(kcslKg.toString());//库存数量
                                
                                businessNoticeReceive.setHzqlsxzdm(3052);//商品粮 转后,划转后粮食性质
                                businessNoticeReceive.setLsxzzbdh(jsonObject.getString("tzdid"));//粮食性质转变单单号
                                //SimpleDateFormat dateFormat= new SimpleDateFormat("yyyy-MM-dd :hh:mm:ss");
                                businessNoticeReceive.setHzrq(new Date());//划转时间

                            }
                            String  lsyqsl = jsonObject.getString("lsyqsl");
//                            BigDecimal s = new BigDecimal(1000);
//                            BigDecimal sumjhsl = new BigDecimal(lsyqsl);
//                            BigDecimal sumCkslss = sumjhsl.multiply(s);
                            //String count = sumCkslss.toString(); //吨转化为公斤

                            businessNoticeReceive.setCount(lsyqsl); //计划数量（吨）
                            businessNoticeReceive.setOutgoingPeriod(jsonObject.getString("ckqx")); //出库期限(日期格式)

                            businessNoticeReceive.setInApplication(1); //启用
                            businessNoticeReceive.setIsNotice(0);//0是可以引用的通知单
                            businessNoticeReceive.setAuditState(0);//下达未审批
                            businessNoticeReceive.setReceiveTime(new Date());//接收数据的时间
                            businessNoticeReceive.setIsSheet(0);//是性质转变单
                            businessNoticeReceiveMapper.insert(businessNoticeReceive);
                           
                        }

                    }else{
                        modelMap.put("msg", "cfbm编码为空");
                        modelMap.put("status", "error");
                    }

                }else{
                    modelMap.put("msg", "通知单或者业务类型为空");
                    modelMap.put("status", "error");
                }
            }
            

        }else{
            modelMap.put("msg", "所传数据不能为空");
            modelMap.put("status", "error");
        }

		return modelMap;
	}



	@Override
	public List<BusinessNoticeReceive> queryByExample(BusinessNoticeReceive businessNoticeReceive) {
		// TODO Auto-generated method stub
		
		
		BusinessNoticeReceiveExample example = new BusinessNoticeReceiveExample();
        Criteria createCriteria = example.createCriteria();
        
        //仓房
        if(businessNoticeReceive.getHouseId()!=null){
        	createCriteria.andHouseIdEqualTo(businessNoticeReceive.getHouseId());
        }
        //货位
        if(businessNoticeReceive.getWareHouseId()!=null){
        	createCriteria.andWareHouseIdEqualTo(businessNoticeReceive.getWareHouseId());
        }
        
      //货位
        if(businessNoticeReceive.getOrgId()!=null){
        	createCriteria.andOrgIdEqualTo(businessNoticeReceive.getOrgId());
        }
        if(businessNoticeReceive.getIsSheet()!=null){
        	createCriteria.andIsSheetEqualTo(businessNoticeReceive.getIsSheet());
        }
        example.setOrderByClause("receive_time desc");
        List<BusinessNoticeReceive> selectByExample = businessNoticeReceiveMapper.selectByExample(example);
        return selectByExample;
        
	}



	@Override
	public List<Map<String, String>> getUserRole(Integer userId) {
		// TODO Auto-generated method stub
		return businessNoticeReceiveMapper.getUserRole(userId);
	}



	@Override
	public void audit(BusinessNoticeReceive receiveNotice, Integer userId, String realName,String orgName,String content) {
		// TODO Auto-generated method stub
		
        //businessApproval.setContent(jsonUserInfo.getString("realName") + "提交"); //提交人
        
		BusinessApproval businessApproval = new BusinessApproval();
		businessApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
        businessApproval.setOperator(userId+"");//已选择的审批人id
        businessApproval.setOperatorName(realName);//已选择的审批人姓名
        businessApproval.setCreateTime(new Date()); //创建时间
        businessApproval.setFromDepartment(orgName); //部门 orgName
    	businessApproval.setProjectName("性质转变单审批");//名称
        businessApproval.setTaskType("propertyTS");//任务类型
    	businessApproval.setResult("同意");//审批结果
    	businessApproval.setApplyTime(receiveNotice.getReceiveTime());//申请时间
        businessApproval.setTaskTypeName(receiveNotice.getLsxzzbdh());//任务类型名
        businessApproval.setIsHide(0);//
        businessApproval.setContent(content);//审批意见
        businessApproval.setProjectId(receiveNotice.getId());
        if(receiveNotice.getAuditState().equals(0)){//仓储部审批
        	//更改该条数据
        	receiveNotice.setCcshr(userId+"");
        	receiveNotice.setAuditState(1);
        	businessNoticeReceiveMapper.updateByPrimaryKeySelective(receiveNotice);
        	
        	//审批表数据的新增
            businessApproval.setTaskName("仓储部经理审批");//任务名称

        }else{
        	
        	if(receiveNotice.getAuditState().equals(1)){//质检审批
        		receiveNotice.setAuditState(2);
        		receiveNotice.setZjshr(userId+"");
        		businessApproval.setTaskName("质检部经理审批");//任务名称
        		
        	}else if(receiveNotice.getAuditState().equals(2)){//统计审批
        		receiveNotice.setAuditState(3);
        		receiveNotice.setTjshr(userId+"");
        		businessApproval.setTaskName("统计部经理审批");//任务名称
        		
        	}else if(receiveNotice.getAuditState().equals(3)){//会计审批
        		receiveNotice.setAuditState(4);
        		receiveNotice.setKjshr(userId+"");
        		businessApproval.setTaskName("会计部经理审批");//任务名称
        	}else if(receiveNotice.getAuditState().equals(4)){//库领导审批
        		receiveNotice.setAuditState(5);//审批完毕
        		receiveNotice.setLdshr(userId+"");
        		businessApproval.setTaskName("库领导审批");//任务名称
        	}
        	
        	//修改本条数据
        	businessNoticeReceiveMapper.updateByPrimaryKeySelective(receiveNotice);

        }
       //增加审批表数据
    	businessApprovalService.add(businessApproval);
        
		
	}



	@Override
	public int queryIsOrAudit(String xybh, String sptDataId,Integer flag) {
		// TODO Auto-generated method stub
		String houseId = "0";
		if(flag.equals(0)){//油罐
			 houseId =feignBasicService.getTankIdBySptDataID(sptDataId);
		}else if(flag.equals(1)){//仓房
			 houseId = feignBasicService.getHouseIdBySptDataID(sptDataId);
		}
		
		//根据仓房或者油罐id 查询是否有为完成审批的性质转变单
		BusinessNoticeReceiveExample example = new BusinessNoticeReceiveExample();
        Criteria createCriteria = example.createCriteria();
        createCriteria.andHouseIdEqualTo(Integer.valueOf(houseId));
        createCriteria.andContractNumberEqualTo(xybh);
        createCriteria.andIsSheetEqualTo(0);
        example.setOrderByClause("receive_time desc");
        List<BusinessNoticeReceive> list = businessNoticeReceiveMapper.selectByExample(example);
		if(list.size()>0 && !list.get(0).getAuditState().equals(5)){
			//查询到有未审批的数据
			return 1;
		}else{
			//没有查询到数据 或者都审批通过 就直接保存
			return 0;
		}
		
	}



	@Override
	public void saveDataRk(String orgId, Integer storehouseId, Integer warehouseId, String grainVarietyName, BigDecimal rksl,
			String lsxzzbdh,String xyh) {
		// TODO Auto-generated method stub
        
		BusinessNoticeReceive businessNoticeReceive = new BusinessNoticeReceive();
        //String orgId = (String) paramMap.get("orgId");
        //Integer storehouseId =  (Integer) paramMap.get("storehouseId");
        // warehouseId =  (Integer) paramMap.get("warehouseId");
        //String pzmc = (String) paramMap.get("pzmc");
       // String hzsl = (String) paramMap.get("hzsl");
        //String lsxzzbdh = (String) paramMap.get("lsxzzbdh");
		System.out.println("orgId:----------------------------"+orgId+"storehouseId:-"+storehouseId+"warehouseId"+"////"+warehouseId);
		Map<String, Object> map = feignAgileService.getDateByChHwh(Integer.valueOf(orgId), storehouseId, warehouseId);
		System.out.println("map:----------------------------"+map);
		Integer grainKind = (Integer) map.get("pz"); //品种
        Double kcsl = (Double) map.get("kcsl");//千克
        Integer grainAttribute = (Integer) map.get("hwxz"); //粮油性质
        businessNoticeReceive.setAuditState(0);//下发未审批
        businessNoticeReceive.setIsNotice(1);//0是1否  是否是可以引用的通知单
        businessNoticeReceive.setOrgId(Integer.valueOf(orgId));
        businessNoticeReceive.setHouseId(storehouseId);
        businessNoticeReceive.setWareHouseId(warehouseId);
        businessNoticeReceive.setCount(rksl+"");
        businessNoticeReceive.setPzmc(grainVarietyName);
        businessNoticeReceive.setGrainKind(grainKind);
        businessNoticeReceive.setGrainAttribute(3052); //入库 转前 3052商品粮
        businessNoticeReceive.setHzqlsxzdm(grainAttribute);//入库 转后 
        businessNoticeReceive.setContractNumber(xyh);
        businessNoticeReceive.setLsxzzbdh(lsxzzbdh);
        businessNoticeReceive.setNoticeNumber(lsxzzbdh);
        businessNoticeReceive.setCrktype("1"); //1入 3出
        BigDecimal s = new BigDecimal(1000);
        System.out.println(kcsl+"kcsl");
        BigDecimal kcslBig = new BigDecimal(String.valueOf(kcsl));
        System.out.println(kcslBig+"kcslBig");

        BigDecimal kcslKg = kcslBig.divide(s);
        businessNoticeReceive.setLssl(kcslKg.toString());//库存数量
        businessNoticeReceive.setHzrq(new Date());
        businessNoticeReceive.setReceiveTime(new Date());
        businessNoticeReceive.setIsSheet(0);
        businessNoticeReceiveMapper.insertSelective(businessNoticeReceive);
        
	}

	@Override
	public Map<String, Object> updateReceiveNotice(String notice) throws Exception {
		Map<String, Object> map = new HashMap<>();
		
		BusinessNoticeReceive businessNoticeReceive = formatObject(notice);
		businessNoticeReceiveMapper.updateByPrimaryKeySelective(businessNoticeReceive);
		map.put("status", 200);
		map.put("msg", "操作成功");
		
		return map;
	}

	@Override
	public void pushHtStatus(String notice) throws Exception {

		String result = "";

		//获取请求的URL地址
		String path = sysCodeService.getSVal(10, "tshtyyzt");

		BusinessNoticeReceive businessNoticeReceive = formatObject(notice);
		List<BusinessContractReceive> list = businessContractReceiveService.queryByExample(businessNoticeReceive.getHtbh(), businessNoticeReceive.getOrgId(), null, null, null);
		if (null != list && list.size() > 0) {
			String htbm = list.get(0).getSptHtid();

			//组装请求参数
			JSONObject object = new JSONObject();
			object.put("htbm", htbm);
			object.put("isChange", "0");
			logger.info("给给市平台发送合同被引用通知数据串："+object.toString());;

			//给市平台发送请求
			result = HTTPUtils.doPost(path, object.toString());

			//保存推送合同引用状态的消息和返回结果
			systemOutsideDataService.addlogger("tshtyyzt", object.toString(), result);
		}
	}

	private BusinessNoticeReceive formatObject(String data) throws Exception {
		ObjectMapper objectMapper = new ObjectMapper();
		BusinessNoticeReceive businessNoticeReceive = objectMapper.readValue(data, BusinessNoticeReceive.class);
		return businessNoticeReceive;
	}

}
