package com.chinaitop.depot.pg.controller;


import com.chinaitop.depot.business.model.OrgInfo;
import com.chinaitop.depot.pg.model.BusinessPgGopsPlan;
import com.chinaitop.depot.pg.model.vo.BusinessPgGopsPlanVO;
import com.chinaitop.depot.pg.model.vo.DataCrkywCplspDefaultVO;
import com.chinaitop.depot.pg.param.BusinessPgGopsPlanPageParam;
import com.chinaitop.depot.pg.service.BusinessPgGopsPlanService;
import com.chinaitop.depot.rp.model.BusinessQcQualityInspection;
import com.chinaitop.depot.rp.model.BusinessRpReport;
import com.chinaitop.depot.rp.model.vo.BusinessRpOutboundVO;
import com.chinaitop.depot.rp.model.vo.BusinessRpReportRecVO;
import com.chinaitop.depot.rp.model.vo.BusinessRpReportVO;
import com.chinaitop.depot.rp.param.BusinessRpBiweeklyReportPageParam;
import com.chinaitop.depot.rp.param.BusinessRpReportPageParam;
import com.chinaitop.depot.rp.service.BusinessRpReportService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 *
 * 成品粮购销计划 前端控制器
 *
 *
 * @author TS
 * @since 2024-06-11
 */
@RestController
@RequestMapping("/pgGopsPlan")
@Api(value= "BusinessPgGopsPlanController", description = "成品粮购销计划")
public class BusinessPgGopsPlanController {

    @Resource
    private BusinessRpReportService businessRpReportService;

    @Resource
    private BusinessPgGopsPlanService businessPgGopsPlanService;



    /**
     * 成品粮购销计划列表
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="成品粮购销计划列表", notes = "查询数据列表，支持分页")
    public PageInfo<Map<String,Object>> getList(BusinessPgGopsPlanPageParam businessPgGopsPlanPageParam){

        List<Map<String,Object>> list = businessPgGopsPlanService.queryByExample(businessPgGopsPlanPageParam);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }


    /**
     * 获取本库区对应的商品列表
     * @return
     * @throws
     */
    @GetMapping("/getCplSpList")
    @ApiOperation(value="获取本库区对应的商品列表", notes = "获取本库区对应的商品列表")
    public List<DataCrkywCplspDefaultVO> getCplSpList(@RequestParam("orgId") @NotBlank(message = "不能为空") String orgId) {

        List<DataCrkywCplspDefaultVO> list = businessPgGopsPlanService.getCplSpList(orgId);
        return list;
    }


    /**
     * 保存或修改成品粮购销计划
     * @param
     * @return
     */
    @RequestMapping(value="/add",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.POST)
    @ApiOperation(value="保存或修改成品粮购销计划", notes = "保存")
    public Map<String, Object> add(@RequestBody BusinessPgGopsPlan businessPgGopsPlan) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {
            modelMap = businessPgGopsPlanService.add(businessPgGopsPlan);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("msg", "失败！");
            modelMap.put("status", "error");
            return modelMap;
        }
        return modelMap;
    }




    /**
     * 删除成品粮购销计划
     * @param
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeById",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.POST)
    @ApiOperation(value="删除成品粮购销计划", notes = "保存")
    public Map<String, Object> removeById(@RequestParam("id")@NotNull(message = "Id不能为空")Integer  id)
            throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            modelMap = businessPgGopsPlanService.removeById(id);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("msg", "删除失败！");
            modelMap.put("status", "error");
            return modelMap;
        }
        return modelMap;
    }





    /**
     * 得到成品粮购销计划
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getPgPlanDetail",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="得到成品粮购销计划", notes = "得到轮换计划接收详情")
    public BusinessPgGopsPlanVO getPgPlanDetail(@RequestParam("id")@NotNull(message = "Id不能为空") Integer id)   {

        BusinessPgGopsPlanVO gopsPlanVO = businessPgGopsPlanService.getPgPlanDetail(id);
        return gopsPlanVO;
    }







}
