package com.chinaitop.depot.pg.service.impl;

import cn.hutool.core.date.DateUtil;
import com.chinaitop.depot.pg.mapper.BusinessPgGopsPlanDetailMapper;
import com.chinaitop.depot.pg.mapper.BusinessPgGopsPlanMapper;
import com.chinaitop.depot.pg.model.BusinessPgGopsPlan;
import com.chinaitop.depot.pg.model.BusinessPgGopsPlanDetail;
import com.chinaitop.depot.pg.model.vo.BusinessPgGopsPlanDetailVO;
import com.chinaitop.depot.pg.model.vo.BusinessPgGopsPlanVO;
import com.chinaitop.depot.pg.model.vo.DataCrkywCplspDefaultVO;
import com.chinaitop.depot.pg.param.BusinessPgGopsPlanPageParam;
import com.chinaitop.depot.pg.service.BusinessPgGopsPlanDetailService;
import com.chinaitop.depot.pg.service.BusinessPgGopsPlanService;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReportGrain;
import com.github.pagehelper.PageHelper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 成品粮粮购销计划 服务实现类
 * </p>
 *
 * @author TS
 * @since 2024-06-11
 */
@Service
public class BusinessPgGopsPlanServiceImpl implements BusinessPgGopsPlanService {

    @Resource
    private BusinessPgGopsPlanDetailMapper businessPgGopsPlanDetailMapper;
    @Resource
    private BusinessPgGopsPlanMapper businessPgGopsPlanMapper;

    /**
     * 成品粮购销计划列表
     *
     * @param pageParam
     * @return
     */
    @Override
    public List<Map<String, Object>> queryByExample(BusinessPgGopsPlanPageParam pageParam) {
        PageHelper.startPage(pageParam.getCurrent(), pageParam.getSize());
        List<Map<String, Object>> list = businessPgGopsPlanMapper.selectByPageParam(pageParam);
        return list;
    }

    /**
     * 保存或修改成品粮购销计划
     *
     * @param businessPgGopsPlan
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Map<String, Object> add(BusinessPgGopsPlan businessPgGopsPlan) {
            Map<String,Object> result = new HashMap<>();
            result.put("status", "error");
            //保存明细品种
            List<BusinessPgGopsPlanDetail>  detailList  =businessPgGopsPlan.getDetailList();
            if (detailList.size() <= 0){
                result.put("msg", "商品明细不能为空");
                return result;
            }
            boolean isAdd = businessPgGopsPlan.getId() == null || businessPgGopsPlan.getId() == 0;
            businessPgGopsPlan.setUpdatedate(new Date());
            if (isAdd){
                businessPgGopsPlan.setCreatedate(new Date());
                businessPgGopsPlanMapper.insertSelective(businessPgGopsPlan); //保存主表信息
            }else{
                businessPgGopsPlanMapper.updateByPrimaryKeySelective(businessPgGopsPlan); //修改主表信息
                //删除明细表数据
                businessPgGopsPlanDetailMapper.deleteByMainId(businessPgGopsPlan.getId());
            }
        for (int i = 0; i < detailList.size(); i++) {
            BusinessPgGopsPlanDetail detail = detailList.get(i);
            detail.setPgGopsPlanId(businessPgGopsPlan.getId());
            detail.setCreatedate(new Date());
            detail.setUpdatedate(new Date());
            businessPgGopsPlanDetailMapper.insertSelective(detail);
        }

            result.put("status", "success");
            result.put("msg", "保存成功");
            return result;
    }

    /**
     * 删除成品粮购销计划
     *
     * @param id
     * @return
     */
    @Override
    public Map<String, Object> removeById(Integer id) {
            Map<String,Object> result = new HashMap<>();
            result.put("status", "error");
            if (businessPgGopsPlanMapper.selectByPrimaryKey(id) == null){
                result.put("msg", "数据不存在，已被删除");
                return result;
            }
            //删除明细表数据
            businessPgGopsPlanDetailMapper.deleteByMainId(id);
            //删除主表数据
            businessPgGopsPlanMapper.deleteByPrimaryKey(id);

            result.put("status", "success");
            result.put("msg", "删除成功");
            return result;
    }

    /**
     * 得到成品粮购销计划
     *
     * @param id
     * @return
     */
    @Override
    public BusinessPgGopsPlanVO getPgPlanDetail(Integer id) {
        BusinessPgGopsPlanVO businessPgGopsPlanVO = businessPgGopsPlanMapper.getPgPlan(id);
        List<BusinessPgGopsPlanDetailVO> detailVoList = businessPgGopsPlanDetailMapper.findPlanDetailList(id);
        businessPgGopsPlanVO.setDetailVoList(detailVoList);
        return businessPgGopsPlanVO;
    }

    /**
     * 获取本库区对应的商品列表
     *
     * @param orgId
     * @return
     */
    @Override
    public List<DataCrkywCplspDefaultVO> getCplSpList(String orgId) {
        return businessPgGopsPlanMapper.getCplSpList(orgId);
    }
}
