package com.chinaitop.depot.rp.controller;


import com.chinaitop.depot.act.service.ActTaskService;
import com.chinaitop.depot.business.model.BusinessContract;
import com.chinaitop.depot.business.model.BusinessDeliveryStorageNotice;
import com.chinaitop.depot.business.model.BusinessStoreWareDetail;
import com.chinaitop.depot.business.service.BusinessContractService;
import com.chinaitop.depot.business.service.BusinessDeliveryStorageNoticeService;
import com.chinaitop.depot.business.service.BusinessFileService;
import com.chinaitop.depot.business.service.BusinessStoreWareDetailService;
import com.chinaitop.depot.rp.model.BusinessQcQualityInspection;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReport;
import com.chinaitop.depot.rp.param.BusinessRpBiweeklyReportPageParam;
import com.chinaitop.depot.rp.service.BusinessRpBiweeklyReportGrainService;
import com.chinaitop.depot.rp.service.BusinessRpBiweeklyReportService;
import com.chinaitop.depot.rp.service.BusinessRpReportService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.management.monitor.StringMonitor;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 *
 * 轮换计划-轮换半月报表 前端控制器
 *
 *
 * @author root
 * @since 2024-05-10
 */
@RestController
@RequestMapping("/business-rp-biweekly-report")
@Api(value= "BusinessRpBiweeklyReportController", tags = "轮换计划-轮换半月报表")
@CrossOrigin
public class BusinessRpBiweeklyReportController {


    @Autowired
    private BusinessRpBiweeklyReportService biweeklyReportService;

    @Resource
    private BusinessRpReportService businessRpReportService;


    /**
     * 轮换计划-轮换半月列表
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="轮换计划-轮换半月列表", notes = "查询数据列表，支持分页")
    public PageInfo<Map<String,Object>> getList(BusinessRpBiweeklyReportPageParam biweeklyReportPageParam) throws Exception {

        List<Map<String,Object>> list = biweeklyReportService.queryByExample(biweeklyReportPageParam);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }
    /**
     * 得到轮换计划下拉列表
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getRpReportList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="得到轮换计划下拉列表", notes = "得到轮换计划下拉列表")
    public List<Map<String,Object>> getRpReportList(String orgId) throws Exception {

        List<Map<String,Object>> list = biweeklyReportService.getRpReportList(orgId);
        return list;
    }
    /**
     * 新增时得到轮换计划详情
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getRpReportDetailsByAdd",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="新增时得到轮换计划详情", notes = "新增时得到轮换计划详情")
    public List<Map<String,Object>> getRpReportDetailsByAdd(@RequestParam("rpReportId") String rpReportId) throws Exception {

        List<Map<String,Object>> list = biweeklyReportService.getRpReportDetailsByAdd(rpReportId);
        return list;
    }


    /**
     * 保存或修改轮换半月报数据
     * @param businessRpBiweeklyReport 主从表信息
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/add",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.POST)
    @ApiOperation(value="保存或修改轮换半月报数据", notes = "保存")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "businessRpBiweeklyReport", value = "主表数据", paramType = "query")
//    })
    public Map<String, Object> add(@RequestBody BusinessRpBiweeklyReport businessRpBiweeklyReport)
            throws Exception {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        try {

            modelMap = biweeklyReportService.add(businessRpBiweeklyReport);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
            return modelMap;
        }
        return modelMap;
    }
    /**
     * 删除轮换半月报数据
     * @param businessRpBiweeklyReportId 半月报主键Id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeById",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.GET)
    @ApiOperation(value="删除轮换半月报数据", notes = "删除")
    public Map<String, Object> removeById(@RequestParam("businessRpBiweeklyReportId") String  businessRpBiweeklyReportId)
            throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            modelMap = biweeklyReportService.removeById(businessRpBiweeklyReportId);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "删除失败！");
            return modelMap;
        }
        return modelMap;
    }
    /**
     * 查看轮换半月报数据
     * @param businessRpBiweeklyReportId 半月报主键Id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getDetail",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.GET)
    @ApiOperation(value="查看轮换半月报数据", notes = "查看详情")
    public Map<String, Object> getDetail(@RequestParam("businessRpBiweeklyReportId") String  businessRpBiweeklyReportId)
            throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            modelMap = biweeklyReportService.getDetail(businessRpBiweeklyReportId);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "查询失败！");
            return modelMap;
        }
        return modelMap;
    }

    /**
     * 根据货位查询粮情卡质检报告
     * @return
     * @throws
     */
    @GetMapping("/sbjk/getFindByWarehouseId")
    @ApiOperation(value="根据货位查询粮情卡质检报告", notes = "根据货位查询粮情卡质检报告")
    public List<BusinessQcQualityInspection> getFindByWarehouseId(@RequestParam("jylb") String jylb, @RequestParam("warehouseId")Integer warehouseId) throws Exception {

        List<BusinessQcQualityInspection> list = businessRpReportService.getQualityInspectionFindByWarehouseId(jylb,warehouseId);
        return list;
    }

}
