package com.chinaitop.depot.rp.controller;


import com.chinaitop.depot.business.model.OrgInfo;
import com.chinaitop.depot.rp.model.BusinessQcQualityInspection;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReport;
import com.chinaitop.depot.rp.model.BusinessRpReport;
import com.chinaitop.depot.rp.model.vo.BusinessRpOutboundVO;
import com.chinaitop.depot.rp.model.vo.BusinessRpReportRecVO;
import com.chinaitop.depot.rp.model.vo.BusinessRpReportVO;
import com.chinaitop.depot.rp.param.BusinessRpBiweeklyReportPageParam;
import com.chinaitop.depot.rp.param.BusinessRpReportPageParam;
import com.chinaitop.depot.rp.service.BusinessRpReportService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.validation.constraints.NotBlank;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 *
 * 轮换计划-上报 前端控制器
 *
 *
 * @author root
 * @since 2024-05-10
 */
@RestController
@RequestMapping("/business-rp-report")
public class BusinessRpReportController {

    @Resource
    private BusinessRpReportService businessRpReportService;

    /**
     * 根据org_id企业查询下面的库区
     *
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findByOrgInfo",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据org_id企业查询下面的库区", notes = "根据org_id企业查询下面的库区")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "单位id", paramType = "form"),
            @ApiImplicitParam(name = "unitInfoId", value = "企业id", paramType = "form")
    })
    public List<OrgInfo> findByOrgInfo(Integer orgId,String unitInfoId) {
        List<OrgInfo> orgInfoList = new ArrayList<>();
        try {
            orgInfoList = businessRpReportService.findByOrgInfo(orgId,unitInfoId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return orgInfoList;
    }

    /**
     * 根据warehouseId查询粮情卡数据
     *
     * @param warehouseId
     * @return
     */
    @RequestMapping(value = "/findByWarehouseInfo",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据warehouseId查询粮情卡数据", notes = "根据warehouseId查询粮情卡数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "warehouseId", value = "货位id", paramType = "form")
    })
    public BusinessRpOutboundVO findByWarehouseInfo(Integer warehouseId) {
        BusinessRpOutboundVO businessRpOutboundVO=new BusinessRpOutboundVO();
        try {

            businessRpOutboundVO = businessRpReportService.findByWarehouseInfo(warehouseId);
            return businessRpOutboundVO;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return businessRpOutboundVO;
    }
    /**
     * 根据org_id查询仓房
     *
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/findByStoreHouseInfo",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据org_id查询仓房", notes = "根据org_id查询仓房")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orgId", value = "单位id", paramType = "form")
    })
    public List<BusinessRpOutboundVO> findByStoreHouseInfo(Integer orgId) {
        List<BusinessRpOutboundVO> orgInfoList = new ArrayList<>();
        try {
            orgInfoList = businessRpReportService.findByStoreHouseInfo(orgId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return orgInfoList;
    }
    /**
     * 根据basicStorehouseId查询货位
     *
     * @param basicStorehouseId
     * @return
     */
    @RequestMapping(value = "/findByWareHouseInfoDatd",produces = MediaType.APPLICATION_JSON_VALUE,method = RequestMethod.GET)
    @ApiOperation(value="根据basicStorehouseId查询货位", notes = "根据basicStorehouseId查询货位")
    public List<BusinessRpOutboundVO> findByWareHouseInfoDatd(Integer basicStorehouseId) {
        List<BusinessRpOutboundVO> orgInfoList = new ArrayList<>();
        try {
            orgInfoList = businessRpReportService.findByWareHouseInfo(basicStorehouseId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return orgInfoList;
    }




    //
    /**
     * 新增时得到轮换计划详情
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getRpReportFindByById",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="新增时得到轮换计划详情", notes = "新增时得到轮换计划详情")
    public BusinessRpReportVO getRpReportDetailsByAdd(Integer rpReportId) throws Exception {

        BusinessRpReportVO list = businessRpReportService.getRpReportFindByById(rpReportId);
        return list;
    }


    /**
     * 根据货位查询粮情卡质检报告
     * @return
     * @throws
     */
    @GetMapping("/getFindByWarehouseId")
    @ApiOperation(value="根据货位查询粮情卡质检报告", notes = "根据货位查询粮情卡质检报告")
    public List<BusinessQcQualityInspection> getQualityInspectionFindByWarehouseId(@RequestParam("jylb") String jylb,@RequestParam("warehouseId")Integer warehouseId) throws Exception {

        List<BusinessQcQualityInspection> list = businessRpReportService.getQualityInspectionFindByWarehouseId(jylb,warehouseId);
        return list;
    }

    /**
     * 根据货位查询粮情卡质检报告
     * @return
     * @throws
     */
    @GetMapping("/sbjk/getFindByWarehouseId")
    @ApiOperation(value="根据货位查询粮情卡质检报告", notes = "根据货位查询粮情卡质检报告")
    public List<BusinessQcQualityInspection> getFindByWarehouseId(@RequestParam("jylb") String jylb,@RequestParam("warehouseId")Integer warehouseId) throws Exception {

        List<BusinessQcQualityInspection> list = businessRpReportService.getQualityInspectionFindByWarehouseId(jylb,warehouseId);
        return list;
    }

    /**
     * 根据质检单号查询质检报告
     * @return
     * @throws
     */
    @GetMapping("/getFindByReportIds")
    @ApiOperation(value="根据质检单号查询质检报告", notes = "根据质检单号查询质检报告")
    public List<BusinessQcQualityInspection> getFindByReportIds(@RequestParam("ids") String ids) throws Exception {

        List<BusinessQcQualityInspection> list = businessRpReportService.getFindByReportIds(ids);
        return list;
    }



    //保存

    /**
     * 保存或修改轮换轮换计划
     * @param
     * @return
     */
    @RequestMapping(value="/add",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.POST)
    @ApiOperation(value="保存或修改轮换轮换计划", notes = "保存")
    public Map<String, Object> add(@RequestBody BusinessRpReport businessRpReport) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        try {

            modelMap = businessRpReportService.add(businessRpReport);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "失败！");
            return modelMap;
        }
        return modelMap;
    }

    /**
     * 轮换计划上报列表
     * @return
     * @throws
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="轮换计划上报列表", notes = "查询数据列表，支持分页")
    public PageInfo<Map<String,Object>> getList(BusinessRpReportPageParam businessRpReportPageParam) throws Exception {

        List<Map<String,Object>> list = businessRpReportService.queryByExample(businessRpReportPageParam);

        PageInfo<Map<String,Object>> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }

    /**
     * 轮换计划接收列表
     * @return
     * @throws
     */
    @RequestMapping(value="/getRecList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="轮换计划接收列表", notes = "查询数据列表，支持分页")
    public PageInfo<Map<String,Object>> getRecList(BusinessRpReportPageParam businessRpReportPageParam) throws Exception {
        System.out.println("----------------------------");

        List<Map<String,Object>> list = businessRpReportService.getRecList(businessRpReportPageParam);
        PageInfo<Map<String,Object>> pageInfo = new PageInfo<>(list);
        return pageInfo;
    }


    /**
     * 删除轮换计划
     * @param
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeById",produces = MediaType.APPLICATION_JSON_VALUE,  method=RequestMethod.POST)
    @ApiOperation(value="删除轮换计划", notes = "保存")
    public Map<String, Object> removeById(@RequestParam("id")Integer  id)
            throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            modelMap = businessRpReportService.removeById(id);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "删除失败！");
            return modelMap;
        }
        return modelMap;
    }





    /**
     * 得到轮换计划接收详情
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getRpReportRecDetail",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="得到轮换计划接收详情", notes = "得到轮换计划接收详情")
    public BusinessRpReportRecVO getRpReportRecDetail(@RequestParam("rpReportId")@NotBlank(message = "轮换计划Id") String rpReportId, @RequestParam("orgId")String orgId) throws Exception {

        BusinessRpReportRecVO report = businessRpReportService.getRpReportRecDetail(rpReportId,orgId);
        return report;
    }







}
