package com.chinaitop.depot.rp.service.impl;

import cn.hutool.core.date.DateUtil;
import com.chinaitop.depot.business.model.BusinessContract;
import com.chinaitop.depot.business.model.BusinessContractExample;
import com.chinaitop.depot.business.model.OrgInfo;
import com.chinaitop.depot.rp.mapper.BusinessRpBiweeklyReportGrainMapper;
import com.chinaitop.depot.rp.mapper.BusinessRpBiweeklyReportGrainStockMapper;
import com.chinaitop.depot.rp.mapper.BusinessRpBiweeklyReportMapper;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReport;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReportGrain;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReportGrainStock;
import com.chinaitop.depot.rp.param.BusinessRpBiweeklyReportPageParam;
import com.chinaitop.depot.rp.service.BusinessRpBiweeklyReportService;
import com.github.pagehelper.PageHelper;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.server.session.InMemoryWebSessionStore;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 轮换计划-轮换半月报表 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-10
 */
@Service
public class BusinessRpBiweeklyReportServiceImpl  implements BusinessRpBiweeklyReportService {
    @Resource
    private BusinessRpBiweeklyReportMapper businessRpBiweeklyReportMapper;
    @Resource
    private BusinessRpBiweeklyReportGrainMapper businessRpBiweeklyReportGrainMapper;
    @Resource
    private BusinessRpBiweeklyReportGrainStockMapper businessRpBiweeklyReportGrainStockMapper;
    @Resource
    private com.chinaitop.depot.business.mapper.OrgInfoMapper orgInfoMapper;
    /**
     * 轮换计划-轮换半月列表
     *
     * @param pageParam
     * @return
     */
    @Override
    public List<Map<String, Object>> queryByExample(BusinessRpBiweeklyReportPageParam pageParam) {

        PageHelper.startPage(pageParam.getCurrent(), pageParam.getSize());
        List<Map<String, Object>> list = businessRpBiweeklyReportMapper.selectByPageParam(pageParam);
        return list;
    }

    /**
     * 得到轮换计划下拉列表
     *
     * @param orgId
     * @return
     */
    @Override
    public List<Map<String, Object>> getRpReportList(String orgId) {
        List<Map<String, Object>> list = businessRpBiweeklyReportMapper.getRpReportList(orgId);
        return list;
    }

    /**
     * 新增时得到轮换计划详情
     *
     * @param rpReportId
     * @return
     */
    @Override
    public List<Map<String, Object>> getRpReportDetailsByAdd(String rpReportId) {
        //当前天在15到月底，则查询1-15号轮入轮出数据
        //当前天1到15号，则查询上一月16号则上月底轮入轮出数据
        //检测当前时间是当月第几天
        int day = DateUtil.thisDayOfMonth();
        String startDate;
        String endDate;
        if (day >= 16-1){ //16号到月底
            Date firstDay = DateUtil.beginOfMonth(new Date());
            startDate = DateUtil.formatDate(firstDay); //1号
            endDate = DateUtil.formatDate((DateUtil.offsetDay(firstDay,14))); //15号
        }else { //1号到15号
            Date preMotnh = DateUtil.offsetMonth(new Date(), -1); //得到上一月
            Date preFirstDay = DateUtil.beginOfMonth(preMotnh); //上有第一天
            startDate = DateUtil.formatDate((DateUtil.offsetDay(preFirstDay, 15))); //16号
            endDate = DateUtil.formatDate(DateUtil.endOfMonth(preMotnh)); //上月最后一天
        }
        List<Map<String, Object>> list = businessRpBiweeklyReportMapper.getRpReportDetailsByAdd(rpReportId,startDate,endDate);
        return list;
    }

    /**
     * 保存或修改轮换半月报数据
     *
     * @param businessRpBiweeklyReport
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Map<String, Object> add(BusinessRpBiweeklyReport businessRpBiweeklyReport) {
        Map<String,Object> result = new HashMap<>();
        result.put("status", "error");
        //保存粮食品种数据
        List<BusinessRpBiweeklyReportGrain>  reportGrainList  =businessRpBiweeklyReport.getReportGrainList();
        if (reportGrainList.size() <= 0){
            result.put("msg", "粮食品种不能为空");
            return result;
        }
        boolean isAdd = businessRpBiweeklyReport.getId() == null || businessRpBiweeklyReport.getId() == 0;
        businessRpBiweeklyReport.setUpdatedate(new Date());
        if (isAdd){
            businessRpBiweeklyReport.setCreatedate(new Date());
            businessRpBiweeklyReport.setReportTime(new Date());
            businessRpBiweeklyReportMapper.insertSelective(businessRpBiweeklyReport); //保存主表信息
        }else{
            businessRpBiweeklyReportMapper.updateByPrimaryKeySelective(businessRpBiweeklyReport); //修改主表信息
            //删除粮食品种与出入库关系表数据
            businessRpBiweeklyReportGrainStockMapper.deleteByMainId(businessRpBiweeklyReport.getId());
            businessRpBiweeklyReportGrainMapper.deleteByMainId(businessRpBiweeklyReport.getId());
        }

        //保存出入库关系数据
        //当前天在15到月底，则查询1-15号轮入轮出数据
        //当前天1到15号，则查询上一月16号则上月底轮入轮出数据
        //检测当前时间是当月第几天
        int day = DateUtil.thisDayOfMonth();
        String startDate;
        String endDate;
        if (day >= 16-1){ //16号到月底
            Date firstDay = DateUtil.beginOfMonth(new Date());
            endDate = DateUtil.formatDate((DateUtil.offsetDay(firstDay,14))); //15号
            startDate = DateUtil.formatDate(firstDay); //1号
        }else { //1号到15号
            Date preMotnh = DateUtil.offsetMonth(new Date(), -1); //得到上一月
            Date preFirstDay = DateUtil.beginOfMonth(preMotnh); //上有第一天
            endDate = DateUtil.formatDate(DateUtil.endOfMonth(preMotnh)); //上月最后一天
            startDate = DateUtil.formatDate((DateUtil.offsetDay(preFirstDay, 15))); //16号
        }

        for (int i = 0; i < reportGrainList.size(); i++) {
            BusinessRpBiweeklyReportGrain grain = reportGrainList.get(i);
            grain.setRpReportId(businessRpBiweeklyReport.getRpReportId());
            grain.setRpBiweeklyReportId(businessRpBiweeklyReport.getId());
            grain.setCreatedate(new Date());
            grain.setUpdatedate(new Date());
            businessRpBiweeklyReportGrainMapper.insertSelective(grain);
            //出入库关系表数据
            businessRpBiweeklyReportGrainStockMapper.insertCk(grain.getId(),businessRpBiweeklyReport.getRpReportId(),grain.getGrainVarietyId(),startDate,endDate);
            businessRpBiweeklyReportGrainStockMapper.insertRk(grain.getId(),businessRpBiweeklyReport.getRpReportId(),grain.getGrainVarietyId(),startDate,endDate);
        }

        result.put("status", "success");
        result.put("msg", "保存成功");
        return result;
    }

    /**
     * 删除轮换半月报数据
     *
     * @param businessRpBiweeklyReportId
     * @return
     */
    @Override
    public Map<String, Object> removeById(String businessRpBiweeklyReportId) {
        Map<String,Object> result = new HashMap<>();
        result.put("status", "error");
        Integer id = Integer.parseInt(businessRpBiweeklyReportId);
        if (businessRpBiweeklyReportMapper.selectByPrimaryKey(id) == null){
            result.put("msg", "数据不存在，已被删除");
            return result;
        }
        //删除粮食品种与出入库关系表数据
        businessRpBiweeklyReportGrainStockMapper.deleteByMainId(id);
        businessRpBiweeklyReportGrainMapper.deleteByMainId(id);
        //删除主表数据
        businessRpBiweeklyReportMapper.deleteByPrimaryKey(id);

        result.put("status", "success");
        result.put("msg", "删除成功");
        return result;
    }

    /**
     * 查看轮换半月报数据
     *
     * @param businessRpBiweeklyReportId
     * @return
     */
    @Override
    public Map<String, Object> getDetail(String businessRpBiweeklyReportId) {
        Map<String,Object> result = new HashMap<>();
        result.put("status", "error");
        Integer id = Integer.parseInt(businessRpBiweeklyReportId);
        BusinessRpBiweeklyReport  businessRpBiweeklyReport = businessRpBiweeklyReportMapper.selectByPrimaryKey(id);
        if (businessRpBiweeklyReportMapper.selectByPrimaryKey(id) == null){
            result.put("msg", "数据不存在，已被删除");
            return result;
        }
        //查询轮换计划名称
        Map<String,Object> map = businessRpBiweeklyReportMapper.queryName(businessRpBiweeklyReport.getRpReportId());
        if (map!=null){
            businessRpBiweeklyReport.setRpReportName(map.getOrDefault("planName","").toString());
            businessRpBiweeklyReport.setRotationYear(map.getOrDefault("rotationYear","").toString());
        }
        //查询orgName
        OrgInfo orgInfo  = orgInfoMapper.selectByPrimaryKey(businessRpBiweeklyReport.getOrgId());
        if (orgInfo !=null)
            businessRpBiweeklyReport.setOrgName(orgInfo.getOrgName());

        //查询粮食品种
        List<BusinessRpBiweeklyReportGrain> list =businessRpBiweeklyReportGrainMapper.selectByMainId(id);
        businessRpBiweeklyReport.setReportGrainList(list);
        result.put("businessRpBiweeklyReport", businessRpBiweeklyReport);
        result.put("status", "success");
        result.put("msg", "查询成功");
        return result;
    }
}
