package com.chinaitop.depot.rp.service.impl;


import com.chinaitop.depot.rp.mapper.BusinessRpOutboundMapper;
import com.chinaitop.depot.rp.mapper.BusinessRpReportMapper;
import com.chinaitop.depot.rp.model.BusinessRpBiweeklyReport;
import com.chinaitop.depot.rp.model.BusinessRpOutbound;
import com.chinaitop.depot.rp.model.vo.BusinessRpOutboundVO;
import com.chinaitop.depot.rp.model.vo.MultipleMapsContainer;
import com.chinaitop.depot.rp.service.BusinessRpOutboundService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 轮换计划-出库信息表 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-10
 */
@Service
public class BusinessRpOutboundServiceImpl  implements BusinessRpOutboundService {

    @Resource
    private BusinessRpOutboundMapper businessRpOutboundMapper;

    @Override
    public BusinessRpOutboundVO getOutband(Integer warehouseId) {
        return businessRpOutboundMapper.getOutband(warehouseId);
    }

//    @Override
//    public BusinessRpOutboundVO findByfindByQualityCheckInfo(Integer warehouseId) {
//        return businessRpOutboundMapper.findByfindByQualityCheckInfo(warehouseId);
//    }

    //根据orgid查询仓房
    @Override
    public List<BusinessRpOutboundVO> findByStoreHouseInfo(Integer orgId) {
        return businessRpOutboundMapper.findByStoreHouseInfo(orgId);
    }

    //根据仓房id查廒间和货位
    @Override
    public List<BusinessRpOutboundVO> findByWareHouseInfo(Integer orgId) {
        return businessRpOutboundMapper.findByWareHouseInfo(orgId);
    }

    @Override
    public MultipleMapsContainer fingBySum(List<BusinessRpOutboundVO> BusinessRpOutboundList) {
        // 使用嵌套HashMap进行分组和计数
        Map<Integer, Map<Integer, Map<Integer, BigDecimal>>> groupMap = new HashMap<>();

        // 用于存储orgname和pzname，因为它们与orgId和pz关联，xzname直接从A实体中读取
        Map<Integer, String> orgNameMap = new HashMap<>();
        Map<Integer, Map<Integer, String>> pzNameMap = new HashMap<>();
        for (BusinessRpOutboundVO bto:BusinessRpOutboundList) {
            Integer orgId = bto.getOrgId();
            Integer pz = bto.getGrainVarietyId();
            Integer xz = bto.getGrainNatureId();
            BigDecimal currentCount = groupMap
                    .computeIfAbsent(orgId, k -> new HashMap<>())
                    .computeIfAbsent(pz, k -> new HashMap<>())
                    .computeIfAbsent(xz, k -> BigDecimal.ZERO);
            groupMap.get(orgId).get(pz).put(xz, currentCount.add(bto.getSealingQuantity()));

            // 存储orgname和pzname
            orgNameMap.putIfAbsent(orgId, bto.getKqmc());
            pzNameMap.computeIfAbsent(orgId, k -> new HashMap<>()).put(pz, bto.getGrainVarietyName());
        }
        MultipleMapsContainer multipleMapsContainer =new MultipleMapsContainer();
        multipleMapsContainer.setMap1(groupMap);
        multipleMapsContainer.setMap2(orgNameMap);
        multipleMapsContainer.setMap3(pzNameMap);


        return multipleMapsContainer;
    }

}
