package com.chinaitop.depot.rp.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.business.mapper.OrgInfoMapper;
import com.chinaitop.depot.business.model.BusinessPlan;
import com.chinaitop.depot.business.model.BusinessPlanExample;
import com.chinaitop.depot.business.model.OrgInfo;
import com.chinaitop.depot.business.model.OrgInfoExample;
import com.chinaitop.depot.rp.mapper.BusinessQcQualityInspectionMapper;
import com.chinaitop.depot.rp.mapper.BusinessRpInboundMapper;
import com.chinaitop.depot.rp.mapper.BusinessRpOutboundMapper;
import com.chinaitop.depot.rp.mapper.BusinessRpReportMapper;
import com.chinaitop.depot.rp.model.*;
import com.chinaitop.depot.rp.model.vo.BusinessRpOutboundVO;
import com.chinaitop.depot.rp.model.vo.BusinessRpReportRecVO;
import com.chinaitop.depot.rp.model.vo.BusinessRpReportVO;
import com.chinaitop.depot.rp.param.BusinessRpReportPageParam;
import com.chinaitop.depot.rp.service.BusinessRpInboundService;
import com.chinaitop.depot.rp.service.BusinessRpOutboundService;
import com.chinaitop.depot.rp.service.BusinessRpReportService;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.prefs.BackingStoreException;

/**
 * <p>
 * 轮换计划-上报 服务实现类
 * </p>
 *
 * @author root
 * @since 2024-05-10
 */
@Service
public class BusinessRpReportServiceImpl implements BusinessRpReportService {

    @Resource
    private BusinessQcQualityInspectionMapper businessQcQualityInspectionMapper;


    @Resource
    private BusinessRpInboundMapper businessRpInboundMapper;

    @Resource
    private BusinessRpOutboundMapper businessRpOutboundMapper;

    @Resource
    private BusinessRpOutboundService businessRpOutboundService;

    @Resource
    private OrgInfoMapper orgInfoMapper;

    @Resource
    private BusinessRpReportMapper businessRpReportMapper;

    //查询库区数据
    @Override
    public BusinessRpOutboundVO findByWarehouseInfo(Integer warehouseId) {


        return businessRpOutboundService.getOutband(warehouseId);
    }


    @Override
    public List<OrgInfo> findByOrgInfo(Integer orgId, String unitInfoId) {
      Map map=new HashMap<>();
        map.put("orgId",orgId);
        map.put("unitInfoId",unitInfoId);

        List<OrgInfo> selectByExample = orgInfoMapper.selectByExample1(map);//获取到库区
        return selectByExample;
    }

    @Override
    public List<BusinessRpOutboundVO> findByStoreHouseInfo(Integer orgId) {
        return businessRpOutboundService.findByStoreHouseInfo(orgId);
    }


     @Override
    public List<BusinessRpOutboundVO> findByWareHouseInfo(Integer basicStorehouseId) {
        return businessRpOutboundService.findByWareHouseInfo(basicStorehouseId);
    }

    /**
     * 新增时得到轮换计划详情
     * @return
     */

    @Override
    public BusinessRpReportVO getRpReportFindByById(Integer rpReportId) {
        BusinessRpReportVO businessRpReportVO =businessRpReportMapper.getRpReportFindByById(rpReportId);

        //BusinessRpReportRecVO businessRpReportRecVO =businessRpReportMapper.getRpReportByById(rpReportId,null);

        List<BusinessRpOutbound> outboundList = businessRpOutboundMapper.findByRpReportId(rpReportId+"",null);
        if(outboundList.size()>0){

            businessRpReportVO.setBusinessRpOutboundList(outboundList);
        }

        List<BusinessRpInbound> inboundList = businessRpInboundMapper.findByRpReportId(rpReportId+"",null);
        if(inboundList.size()>0){
            businessRpReportVO.setBusinessRpInboundList(inboundList);
        }



        return businessRpReportVO;
    }
    @Transactional(rollbackFor = Exception.class)
    @Override
    public Map<String, Object> add(BusinessRpReport businessRpReport) {
        Map<String,Object> result = new HashMap<>();
        List<BusinessRpInbound>  businessRpInbound = businessRpReport.getBusinessRpInboundList();
        BusinessRpInboundExample businessRpInboundExample =new BusinessRpInboundExample();
       businessRpReport.setUpdateTime(new Date());
        if(businessRpReport.getStatus()==0){
            if(businessRpReport.getId()!=null){
                businessRpReportMapper.updateByPrimaryKeySelective(businessRpReport);
                businessRpInboundMapper.deleteByReportId(businessRpReport.getId());
                businessRpOutboundMapper.deleteByReportId(businessRpReport.getId());
                List<BusinessRpInbound> inList =businessRpReport.getBusinessRpInboundList();
                for (BusinessRpInbound br: inList) {

                    br.setCreatedate(new Date());
                    br.setUpdatedate(new Date());
                    br.setRpReportId(businessRpReport.getId());
                    businessRpInboundMapper.insertSelective(br);
                }
                List<BusinessRpOutbound> outlist =businessRpReport.getBusinessRpOutboundList();
                for (BusinessRpOutbound ou: outlist) {
                    ou.setCreatedate(new Date());
                    ou.setUpdatedate(new Date());
                    ou.setRpReportId(businessRpReport.getId());
                    businessRpOutboundMapper.insertSelective(ou);
                }
            }else{
                businessRpReport.setCreateTime(new Date());
                businessRpReport.setUpdateTime(new Date());
                businessRpReportMapper.insert(businessRpReport);
                List<BusinessRpInbound> inList =businessRpReport.getBusinessRpInboundList();
                for (BusinessRpInbound br: inList) {
                    br.setCreatedate(new Date());
                    br.setUpdatedate(new Date());
                    br.setRpReportId(businessRpReport.getId());
                    businessRpInboundMapper.insertSelective(br);
                }
                List<BusinessRpOutbound> outlist =businessRpReport.getBusinessRpOutboundList();
                for (BusinessRpOutbound ou: outlist) {
                    ou.setCreatedate(new Date());
                    ou.setUpdatedate(new Date());
                    ou.setRpReportId(businessRpReport.getId());
                    businessRpOutboundMapper.insertSelective(ou);
                }
            }

        }else{//提交

            if(businessRpReport.getId()!=null){
                //根据id查找主表数据
                BusinessRpReportVO businessRpReportVO =businessRpReportMapper.getRpReportFindByById(businessRpReport.getId());
                if(businessRpReportVO!=null){
                    result.put("status", "error");
                    result.put("msg", "请填写数据后再执行上传操作");
                }
                businessRpReport.setReportTime(new Date());
                businessRpReportMapper.updateByPrimaryKeySelective(businessRpReport);
                List<BusinessRpInbound> inList =businessRpReport.getBusinessRpInboundList();
                if(inList != null && !inList.isEmpty()){
                    businessRpInboundMapper.deleteByReportId(businessRpReport.getId());
                    for (BusinessRpInbound br: inList) {
                        br.setCreatedate(new Date());
                        br.setUpdatedate(new Date());
                        br.setRpReportId(businessRpReport.getId());
                        businessRpInboundMapper.insertSelective(br);
                    }
                }
                List<BusinessRpOutbound> outlist =businessRpReport.getBusinessRpOutboundList();
               if(outlist != null && !outlist.isEmpty()){
                   businessRpOutboundMapper.deleteByReportId(businessRpReport.getId());
                   for (BusinessRpOutbound ou: outlist) {
                       ou.setCreatedate(new Date());
                       ou.setUpdatedate(new Date());
                       ou.setRpReportId(businessRpReport.getId());
                       businessRpOutboundMapper.insertSelective(ou);
                   }
               }


            }else{//保存

                businessRpReport.setCreateTime(new Date());
                businessRpReport.setUpdateTime(new Date());
                businessRpReport.setReportTime(new Date());
                businessRpReportMapper.insert(businessRpReport);
                List<BusinessRpInbound> inList =businessRpReport.getBusinessRpInboundList();
                for (BusinessRpInbound br: inList) {
                    br.setCreatedate(new Date());
                    br.setUpdatedate(new Date());
                    br.setRpReportId(businessRpReport.getId());
                    businessRpInboundMapper.insertSelective1(br);
                }
                List<BusinessRpOutbound> outlist =businessRpReport.getBusinessRpOutboundList();
                for (BusinessRpOutbound ou: outlist) {
                    ou.setCreatedate(new Date());
                    ou.setUpdatedate(new Date());
                    ou.setRpReportId(businessRpReport.getId());
                    businessRpOutboundMapper.insertSelective(ou);
                }
            }

        }
        result.put("status", "success");
        result.put("msg", "成功");
        return result;
    }

    @Override
    public List<Map<String, Object>> queryByExample(BusinessRpReportPageParam pageParam) {
        PageHelper.startPage(pageParam.getCurrent(), pageParam.getSize());
        List<Map<String, Object>> list = businessRpReportMapper.selectByPageParam(pageParam);
        return list;
    }

    @Override
    public Map<String, Object> removeById(Integer id) {
        Map<String,Object> result = new HashMap<>();
        result.put("status", "error");
        if (businessRpReportMapper.selectByPrimaryKey(id) == null){
            result.put("msg", "数据不存在，已被删除");
            return result;
        }
        //删除粮食品种与出入库关系表数据
        businessRpInboundMapper.deleteByReportId(id);
        businessRpOutboundMapper.deleteByReportId(id);
        //删除主表数据
        businessRpReportMapper.deleteByPrimaryKey(id);

        result.put("status", "success");
        result.put("msg", "删除成功");
        return result;
    }

    /**
     * 轮换计划接收列表
     *
     * @param pageParam
     * @return
     */
    @Override
    public List<Map<String, Object>> getRecList(BusinessRpReportPageParam pageParam) {
        PageHelper.startPage(pageParam.getCurrent(), pageParam.getSize());
        List<Map<String, Object>> list = businessRpReportMapper.selectRecListByPageParam(pageParam);
        return list;
    }

    /**
     * 得到轮换计划接收详情
     *
     * @param rpReportId
     * @param orgId
     * @return
     */
    @Override
    public BusinessRpReportRecVO getRpReportRecDetail(String rpReportId, String orgId) {
        BusinessRpReportRecVO businessRpReportRecVO =businessRpReportMapper.getRpReportByById(rpReportId,orgId);

        List<BusinessRpOutbound> outboundList = businessRpOutboundMapper.findByRpReportId(rpReportId,orgId);
        businessRpReportRecVO.setBusinessRpOutboundList(outboundList);

        List<BusinessRpInbound> inboundList = businessRpInboundMapper.findByRpReportId(rpReportId,orgId);
        businessRpReportRecVO.setBusinessRpInboundList(inboundList);

        return businessRpReportRecVO;
    }
    //获取出库质检报告
    @Override
    public List<BusinessQcQualityInspection> getQualityInspectionFindById(String rpReportId, Integer warehouseId, String jylb,Integer inspectionReportId) {
        List<BusinessQcQualityInspection> bQQList =new ArrayList<>();
            bQQList=  businessQcQualityInspectionMapper.getQualityInspectionFindById(rpReportId,warehouseId,jylb,inspectionReportId);

        return null;
    }

    @Override
    public List<BusinessQcQualityInspection> getQualityInspectionFindByWarehouseId(String jylb,Integer warehouseId) {


    	Map<String,Object> map = new HashMap<String,Object>();
    	map.put("jylb", jylb);
    	map.put("warehouseId", warehouseId);
        List<BusinessQcQualityInspection> list =businessQcQualityInspectionMapper.getQualityInspectionFindByWarehouseId(map);
        return list;
    }

    @Override
    public List<BusinessQcQualityInspection> getFindByReportIds(String ids) {
        List<BusinessQcQualityInspection> list = new ArrayList<>();
        try {
            if (ids.contains(",")) {
                String[] idArray = ids.split(",");
                for (String idStr : idArray) {
                    int id = Integer.parseInt(idStr);
                    BusinessQcQualityInspection inspection = businessQcQualityInspectionMapper.selectByPrimaryKey(id);
                    list.add(inspection);
                }
            } else {
                int id = Integer.parseInt(ids);
                list.add(businessQcQualityInspectionMapper.selectByPrimaryKey(id));
            }
        } catch (NumberFormatException e) {
            // 处理ID转换失败的情况
            // 可以记录日志、抛出自定义异常或返回错误信息
            System.err.println("Failed to parse ID from string: " + ids);
        }

        return list;
    }


}
